Installation
============

Install with ``pip`` or ``pipenv``:

.. code:: python

  pip install django-pyc

Add ``django_pyc`` to your installed apps in your settings.py file:

.. code:: python

  INSTALLED_APPS = [
      'django_pyc',
      ...
  ]
